#include <WiFi.h>
#include <WebServer.h>
#include <ESPmDNS.h>
#include <SPIFFS.h>

const char* ssid = "XXXXXX";
const char* password = "YYYYYY";

WebServer server(80);

#define LED_pin 2
bool LED_status = LOW;

void setup() {
  Serial.begin(115200);
  pinMode(LED_pin, OUTPUT);
  digitalWrite(LED_pin, 0);

  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  Serial.println("");

  // Wait for connection
  while (WiFi.status() != WL_CONNECTED){
    delay(500);
    Serial.print(".");
  }
  
  Serial.println("");
  Serial.print("Connected to ");
  Serial.println(ssid);
  Serial.print("IP address: ");
  Serial.println(WiFi.localIP());

  if (MDNS.begin("esp32")) {
    Serial.println("MDNS responder started");
  }

  server.on("/", handleRoot);
  server.on("/led_on", handle_led_on);
  server.on("/led_off", handle_led_off);
  server.onNotFound(handleWebRequests); 
  
  server.begin();
  Serial.println("HTTP server started");

  SPIFFS.begin();
}

void loop() {
  server.handleClient();
}

String load_HD() {
  File dataFile;
  String line;
  
    dataFile = SPIFFS.open("/index_hd.html", FILE_READ);
    while(dataFile.available()) 
      line += (dataFile.readStringUntil('\n') + "\n");
    dataFile.close();

    return line;
}

void handleWebRequests()
{
  String dataType = "text/plain";
  String path;
  File dataFile;
  int flg=0;
   
    path = server.uri();
    if(path.endsWith(".css")) { dataType = "text/css"; flg=1; }
    else if(path.endsWith(".js")) { dataType = "application/javascript"; flg=1; }
    else if(path.endsWith(".png")) { dataType = "image/png"; flg=1; }
    else if(path.endsWith(".gif")) { dataType = "image/gif"; flg=1; }
    else if(path.endsWith(".jpg")) { dataType = "image/jpeg"; flg=1; }
    delay(5);
    
    if(flg)
    {
      dataFile = SPIFFS.open(path.c_str(), FILE_READ);
      server.streamFile(dataFile, dataType);
      dataFile.close();
      delay(5);
    }
    else
    {
      String message = "File Not Found\n\n";
      message += "URI: ";
      message += server.uri();
      message += "\nMethod: ";
      message += (server.method() == HTTP_GET) ? "GET" : "POST";
      message += "\nArguments: ";
      message += server.args();
      message += "\n";
      for (uint8_t i = 0; i < server.args(); i++) {
        message += " " + server.argName(i) + ": " + server.arg(i) + "\n";
      }
      server.send(404, "text/plain", message);      
    }
}

void handleRoot() {
  LED_status = LOW;
  digitalWrite(LED_pin, LOW);
  server.send(200, "text/html", SendHTML(LED_status)); 
}

void handle_led_on() {
  LED_status = HIGH;
  digitalWrite(LED_pin, HIGH);
  server.send(200, "text/html", SendHTML(true)); 
}

void handle_led_off() {
  LED_status = LOW;
  digitalWrite(LED_pin, LOW);
  server.send(200, "text/html", SendHTML(false)); 
}

String SendHTML(uint8_t led_stat){
  String ptr;

  ptr = load_HD();
  if(led_stat)
    {
      ptr +="<a class='button button-off' href='/led_off'>OFF</a>\n";
      ptr +="<div id='a' title='1'></div>\n";
    }
  else
    {
      ptr +="<a class='button button-on' href='/led_on'>ON</a>\n";
      ptr +="<div id='a' title='0'></div>\n";
    }
  ptr +="<script type='text/javascript' src='/test.js'></script>\n";

  ptr +="</body>\n";
  ptr +="</html>\n";
  return ptr;
}
